@@ -22,6 +22,7 @@ else:
 from datetime import datetime, timedelta, timezone
 
 CONTENT_TYPE="application/arson"
+__version__="0.0.3"
 
 reserved_tags = set("""
         bool int float complex
@@ -42,9 +43,9 @@ flt_b10 = re.compile(r"\.[\d_]+")
 exp_b10 = re.compile(r"[eE](?:\+|-)?[\d+_]")
 
 string_dq = re.compile(
-    r'"(?:[^"\\\n\x00-\x1F\uD800-\uDFFF]|\\(?:[\'"\\/bfnrt]|\r?\n|x[0-9a-fA-F]{2}|u[0-9a-fA-F]{4}|U[0-9a-fA-F]{8}))*"')
+    r'"(?:[^"\\\n\x00-\x1F\x7F-\x9F\uD800-\uDFFF]|\\(?:[\'"\\/bfnrt]|\r?\n|x[0-9a-fA-F]{2}|u[0-9a-fA-F]{4}|U[0-9a-fA-F]{8}))*"')
 string_sq = re.compile(
-    r"'(?:[^'\\\n\x00-\x1F\uD800-\uDFFF]|\\(?:[\"'\\/bfnrt]|\r?\n|x[0-9a-fA-F]{2}|u[0-9a-fA-F]{4}|U[0-9a-fA-F]{8}))*'")
+    r"'(?:[^'\\\n\x00-\x1F\x7F-\x9F\uD800-\uDFFF]|\\(?:[\"'\\/bfnrt]|\r?\n|x[0-9a-fA-F]{2}|u[0-9a-fA-F]{4}|U[0-9a-fA-F]{8}))*'")
 
 tag_name = re.compile(r"@(?!\d)\w+[ ]+")
 identifier = re.compile(r"(?!\d)[\w\.]+")
@@ -582,7 +583,7 @@ class Codec:
                 buf.write(": ")
                 self.dump_arson(v, buf, transform)
             buf.write('}')
-        elif isinstance(obj, dict):
+        elif isinstance(obj, dict): # if dict is pre 3.7, then no order preserving
             buf.write('@dict {')
             first = True
             for k in sorted(obj.keys()):
@@ -736,9 +737,10 @@ b"
             if obj != out:
                 raise AssertionError(
                     'failed second trip {} != {}'.format(obj, out))
+    return True
 
-    print('tests passed')
 
 if __name__ == '__main__':
-    run_tests(parse, dump)
+    if run_tests(parse, dump):
+        print('tests passed')
 
